@@ -5,21 +5,14 @@ from contextlib import nullcontext as does_not_raise
 import pytest
 
 import narwhals as nw
-from tests.utils import Constructor
-from tests.utils import ConstructorEager
-from tests.utils import assert_equal_data
+from tests.utils import Constructor, ConstructorEager, assert_equal_data
 
 
 def test_unary(constructor: Constructor, request: pytest.FixtureRequest) -> None:
     if "ibis" in str(constructor):
         request.applymarker(pytest.mark.xfail)
 
-    data = {
-        "a": [1, 3, 2],
-        "b": [4, 4, 6],
-        "c": [7.0, 8.0, None],
-        "z": [7.0, 8.0, 9.0],
-    }
+    data = {"a": [1, 3, 2], "b": [4, 4, 6], "c": [7.0, 8.0, None], "z": [7.0, 8.0, 9.0]}
     result = nw.from_native(constructor(data)).select(
         a_mean=nw.col("a").mean(),
         a_median=nw.col("a").median(),
@@ -46,12 +39,7 @@ def test_unary(constructor: Constructor, request: pytest.FixtureRequest) -> None
 
 
 def test_unary_series(constructor_eager: ConstructorEager) -> None:
-    data = {
-        "a": [1, 3, 2],
-        "b": [4, 4, 6],
-        "c": [7.0, 8.0, None],
-        "z": [7.0, 8.0, 9.0],
-    }
+    data = {"a": [1, 3, 2], "b": [4, 4, 6], "c": [7.0, 8.0, None], "z": [7.0, 8.0, 9.0]}
     df = nw.from_native(constructor_eager(data), eager_only=True)
     result = {
         "a_mean": [df["a"].mean()],
