@@ -3,9 +3,7 @@ from __future__ import annotations
 import pytest
 
 import narwhals as nw
-from tests.utils import DUCKDB_VERSION
-from tests.utils import Constructor
-from tests.utils import assert_equal_data
+from tests.utils import DUCKDB_VERSION, Constructor, assert_equal_data
 
 
 def test_add(constructor: Constructor) -> None:
